Package: svylme
Title: Linear Mixed Models for Complex Survey Data
Version: 1.5-1
Authors@R: person("Thomas", "Lumley", email = "t.lumley@auckland.ac.nz",
  role = c("aut", "cre"))
Description: Linear mixed models for complex survey data, by pairwise composite likelihood, as described in Lumley & Huang (2023) <arXiv:2311.13048>. Supports nested and crossed random effects, and correlated random effects as in genetic models.  Allows for multistage sampling and for other designs where pairwise sampling probabilities are specified or can be calculated. 
Imports: minqa, Matrix, lme4, methods, utils, stats
Depends: survey, R (>= 3.5.0)
License: GPL-3
Maintainer: Thomas Lumley <t.lumley@auckland.ac.nz>
NeedsCompilation: no
Packaged: 2024-02-04 21:25:13 UTC; tlum005
Author: Thomas Lumley [aut, cre]
Repository: CRAN
Date/Publication: 2024-02-06 16:40:02 UTC
Built: R 4.6.0; ; 2026-04-28 12:06:03 UTC; unix
